@@ -15,9 +15,12 @@ wlrcal<-function(n=10,te=c(1,2,3),tfix=2.0,dd1=c(1,0,1),dd0=c(0,1,0),r1=c(1,2,3)
   nt<-length(te)
   nw<-ncol(weights)
   xtest<-xvtest<-xlr<-rep(0,nw)
+  xlcor<-matrix(0,nrow=nw,ncol=nw)
   abc2<-.Fortran("xwlrcal",as.integer(n),as.integer(nt),as.double(te),as.double(tfix),
                  as.double(dd1),as.double(dd0),as.double(r1),as.double(r0),
                  as.integer(nw),as.double(weights),as.double(eps),
-                 xtest=as.double(xtest),xvtest=as.double(xvtest),xlr=as.double(xlr))
-  list(test=abc2$xtest,var=abc2$xvtest,wlr=abc2$xlr)
+                 xtest=as.double(xtest),xvtest=as.double(xvtest),xlr=as.double(xlr),xlcor=as.double(xlcor))
+  list(test=abc2$xtest,var=abc2$xvtest,wlr=abc2$xlr,wlcor=matrix(abc2$xlcor,ncol=nw,byrow=TRUE))
 }
+
+
