@@ -170,17 +170,20 @@ SUBROUTINE XPWEFVPLUS(NT,NR,T,R1,R2,R3,R4,R5,R6,TCHANGE,TYPE,RP2,EPS,FX)
    ELSE IF (TYPE==2) THEN
       CALL XPWEFV4TYPE2(NT,NR,T,R1+R3,R2,R3,R6,TCHANGE,EPS,FX)
    ELSE IF (TYPE==3) THEN
-      !CALL XPWEFV4TYPE2(NT,NR,T,R1+R3,R2,R3,R6,TCHANGE,EPS,TEM1) !CHANGED
-      ! USE R4 TO REPLACE R2                                      !CHANGED
-      !CALL XPWEFV4(NT,NR,T,R4,R4+R6,R3,R1+R3-R4,TCHANGE,EPS,TEM2)!CHANGED 
-      !FX=RP2*TEM1+(1.0-RP2)*TEM2                                 !CHANGED
-      
       PIR2=RP2*R2
       PIR4=(1.0-RP2)*R4
       RONE=1.0
       CALL XPWEFV6(NT,NR,T,R1+R3-PIR4,PIR2,R3,PIR4+R6,RONE,PIR2,TCHANGE,EPS,TEM1)
       CALL XPWEFV6(NT,NR,T,R1+R3-PIR4,PIR2,R3,PIR4+R6,PIR4,RONE,TCHANGE,EPS,TEM2) 
       FX=TEM1+TEM2
+   ELSE IF (TYPE==4) THEN
+      CALL XPWEFV4TYPE2(NT,NR,T,R1+R3,R2,R3,R6,TCHANGE,EPS,TEM1) 
+      CALL XPWEFV4(NT,NR,T,R4,R4+R6,R3,R1+R3-R4,TCHANGE,EPS,TEM2)
+      FX=RP2*TEM1+(1.0-RP2)*TEM2                                 
+   ELSE IF (TYPE==5) THEN
+      CALL XPWEFV4TYPE2(NT,NR,T,R1+R3,R2,R3,R6,TCHANGE,EPS,TEM1)
+      CALL XPWEFV4TYPE2(NT,NR,T,R1+R3,R4,R3,R6,TCHANGE,EPS,TEM2)
+      FX=RP2*TEM1+(1.0-RP2)*TEM2                                 
    ELSE
       CALL XPWEFV4(NT,NR,T,R2,R2+R6,R3,R1+R3-R2,TCHANGE,EPS,FX)
    END IF
@@ -216,7 +219,7 @@ SUBROUTINE XPWECXPWU(NT,NR,NU,T,TAUR,U,UT,R1,R2,R3,R4,R5,RC,TCHANGE,TYPE,RP2,EPS
          CALL XPWEFVPLUS(N1,NR,TEMP,R1,R2,R3,R4,R5,RC,TCHANGE,TYPE,RP2,EPS,FX4)
          CALL XPWEFV2(N1,NR,TEMP,R1,R1+R3+RC,TCHANGE,EPS,FX2)
          A=FX4(:,1)+FX2(:,1);A0=TEMP*A;A1=FX4(:,2)+FX2(:,2)
-8         DU(I)=SUM(U*(A0(1:NU)-A0(2:N1)))-SUM(U*(A1(1:NU)-A1(2:N1)))
+         DU(I)=SUM(U*(A0(1:NU)-A0(2:N1)))-SUM(U*(A1(1:NU)-A1(2:N1)))
          DUPRIME(I)=SUM(U*(A(1:NU)-A(2:N1)))
       END DO
       DEALLOCATE(TEMP,TM,FX4,FX2,A,A0,A1)
@@ -1795,31 +1798,3 @@ SUBROUTINE XPWEFV6(NT,NR,TIN,R1,R2,R3,R4,R5,R6,TCHANGE,EPS,FX)
    RETURN
 END SUBROUTINE XPWEFV6
 
-!!!Added 3/24/2018
-SUBROUTINE SOLVEABC(NT,NP,T,PHIT,WEIGHT,A0,B0,C1,C2,Q,QFLAT,PHIFLAT)
-!DEC$ ATTRIBUTES DLLEXPORT,C,REFERENCE,ALIAS:'solveabc_'::SOLVEABC
-   IMPLICIT NONE
-   INTEGER,INTENT(IN)::NT,NP
-   REAL(8),INTENT(IN)::T(NT),PHIT(NT),WEIGHT(NT),A0(NP),B0(NP),C1,C2
-   REAL(8),INTENT(OUT)::Q(NP),QFLAT(NP),PHIFLAT(NP)
-
-   INTEGER::I,J,K
-   REAL(8)::TEMP1(NT),TEMP2(NT),M1,M2,M3,TT(NT),WT
-
-   TT=(T-C1)/(C2-C1)
-   Q=0.0;WT=SUM(WEIGHT)
-   DO I=1,NP,1
-      TEMP1=(1.0-TT**A0(I)+TT**B0(I))
-      TEMP2=TEMP1/PHIT
-      M1=SUM(WEIGHT*TEMP1)/WT
-      M2=SUM(WEIGHT*TEMP2)/WT
-      M3=SUM(WEIGHT*PHIT)/WT
-      QFLAT(I)=SUM(WEIGHT*(TEMP1-M1)**2)/WT
-      QFLAT(I)=DSQRT(QFLAT(I))/M1
-      Q(I)=SUM(WEIGHT*(TEMP2-M2)**2)/WT
-      Q(I)=DSQRT(Q(I))/M2
-      PHIFLAT(I)=SUM(WEIGHT*(PHIT-M3)**2)/WT
-      PHIFLAT(I)=DSQRT(PHIFLAT(I))
-   END DO
-   RETURN
-END SUBROUTINE SOLVEABC
